pub enum TakeOption {
MustExist,
DenyExisting,
Take {
make: bool,
},
}Expand description
Take option
Variants
MustExist
Must exist
DenyExisting
Deny existing
Take
Just take whatever it is
Fields
If the path does not exist, and this flag is
make: boolIf the path does not exist, and this flag is true, make it
- If
PathKind::Directoryis used, make new directory viafs::create_dir_all(). - If
PathKind::Fileis used, make new empty file viaFile::create().